@@ -263,15 +263,15 @@ class Variable:
         section = self.parent.iniCache[self.name]['section']
         value = self.parent.unserialize(self.type,
                                  value.encode('utf-8'))
-        try:
-            if self.mode == READONLY:
-                raise VariableError(
-                    _("Attempt to rewrite readonly variable %s")%
-                    varname)
-            else:
+        if self.mode == READONLY:
+            raise VariableError(
+                _("Attempt to rewrite readonly variable %s")%
+                self.name)
+        else:
+            try:
                 self._set(value)
-        except Exception as e:
-            return False
+            except Exception as e:
+                return False
         return True
 
     def _get(self):
@@ -1305,7 +1305,10 @@ class DataVars(SimpleDataVars):
         if zipVars is None:
             zipVars = self.ZipVars
         if func:
-            filterFunc = func
+            if func.func_code.co_argcount > 1:
+                filterFunc = lambda x:func(*x[:func.func_code.co_argcount])
+            else:
+                filterFunc = func
         elif eq != None:
             filterFunc = lambda x:x[0] == eq
         elif ne != None:
