@@ -110,7 +110,7 @@ class process:
         self.cwd = kwarg.get("cwd",None)
         self.command = getProgPath(command)
         if not self.command:
-            raise FilesError(_("Program %s is not found")%
+            raise FilesError(_("Command not found '%s'")%
                              command)
         self.command = [self.command] + list(params)
         self.stdin = stdin
@@ -954,7 +954,7 @@ def sambaPasswordCheck(username,password,server,resource):
     """
     smbclient = getProgPath('/usr/sbin/smbclient')
     if not smbclient:
-        raise FilesError(_("Command smbclient is not found"))
+        raise FilesError(_("Command not found '%s'")%"smbclint")
     p = process(smbclient,"-U",username,"//%s/%s"%(server,resource),
                 envdict={'PASSWD':password})
     return p.success()
